package com.fs.hisStore.service;

import com.fs.hisStore.domain.FsIntegralGoodsScrm;
import com.fs.hisStore.param.FsIntegralGoodsListUParam;
import com.fs.hisStore.vo.FsIntegralGoodsListUVO;
import com.fs.hisStore.vo.FsIntegralGoodsListVO;

import java.util.List;

/**
 * 积分商品Service接口
 *
 * @author fs
 * @date 2023-11-02
 */
public interface IFsIntegralGoodsScrmService
{
    /**
     * 查询积分商品
     *
     * @param goodsId 积分商品主键
     * @return 积分商品
     */
    public FsIntegralGoodsScrm selectFsIntegralGoodsByGoodsId(Long goodsId);

    /**
     * 查询积分商品列表
     *
     * @param fsIntegralGoods 积分商品
     * @return 积分商品集合
     */
    public List<FsIntegralGoodsScrm> selectFsIntegralGoodsList(FsIntegralGoodsScrm fsIntegralGoods);

    /**
     * 新增积分商品
     *
     * @param fsIntegralGoods 积分商品
     * @return 结果
     */
    public int insertFsIntegralGoods(FsIntegralGoodsScrm fsIntegralGoods);

    /**
     * 修改积分商品
     *
     * @param fsIntegralGoods 积分商品
     * @return 结果
     */
    public int updateFsIntegralGoods(FsIntegralGoodsScrm fsIntegralGoods);

    /**
     * 批量删除积分商品
     *
     * @param goodsIds 需要删除的积分商品主键集合
     * @return 结果
     */
    public int deleteFsIntegralGoodsByGoodsIds(Long[] goodsIds);

    /**
     * 删除积分商品信息
     *
     * @param goodsId 积分商品主键
     * @return 结果
     */
    public int deleteFsIntegralGoodsByGoodsId(Long goodsId);

    List<FsIntegralGoodsListVO> selectFsIntegralGoodsListVO(FsIntegralGoodsScrm fsIntegralGoods);

    List<FsIntegralGoodsListUVO> selectFsIntegralGoodsListUVO(FsIntegralGoodsListUParam param);

    String importIntegralGoodsService(List<FsIntegralGoodsScrm> list);
}
